<?php
require_once '../../cors/cors.php';
require_once '../../config/database.php';
require_once '../../config/auth.php';

if ($_SERVER['REQUEST_METHOD'] == 'GET') {
    // Get the token from the Authorization header
    $headers = apache_request_headers();
    $authHeader = $headers['Authorization'] ?? '';

    if (!$authHeader || !preg_match('/Bearer\s(\S+)/', $authHeader, $matches)) {
        http_response_code(401); // Unauthorized
        echo json_encode(['error' => 'Unauthorized. Token is required.']);
        exit;
    }

    $token = $matches[1];
    $userData = validateToken($token);

    if (!$userData) {
        http_response_code(401); // Unauthorized
        echo json_encode(['error' => 'Invalid or expired token']);
        exit;
    }

    // Get workspace ID from query parameters
    $workspaceId = $_GET['workspace_id'] ?? '';

    if (empty($workspaceId)) {
        http_response_code(400); // Bad Request
        echo json_encode(['error' => 'Workspace ID is required']);
        exit;
    }

    // Fetch boards under the specified workspace
    $stmt = $conn->prepare("SELECT id, name, description, created_at FROM boards WHERE workspace_id = ?");
    $stmt->bind_param("i", $workspaceId);
    $stmt->execute();
    $result = $stmt->get_result();

    $boards = [];
    while ($row = $result->fetch_assoc()) {
        $boards[] = $row;
    }

    echo json_encode($boards);

    $stmt->close();
} else {
    http_response_code(405); // Method Not Allowed
    echo json_encode(['error' => 'Only GET method is allowed']);
}
