<?php
require_once '../../cors/cors.php';
require_once '../../config/database.php';
require_once '../../config/auth.php';

if ($_SERVER['REQUEST_METHOD'] == 'POST') {
    // Get the token from the Authorization header
    $headers = apache_request_headers();
    $authHeader = $headers['Authorization'] ?? '';

    if (!$authHeader || !preg_match('/Bearer\s(\S+)/', $authHeader, $matches)) {
        http_response_code(401); // Unauthorized
        echo json_encode(['error' => 'Unauthorized. Token is required.']);
        exit;
    }

    $token = $matches[1];
    $userData = validateToken($token);

    if (!$userData) {
        http_response_code(401); // Unauthorized
        echo json_encode(['error' => 'Invalid or expired token']);
        exit;
    }

    // Get the card data
    $listId = $_POST['list_id'] ?? '';
    $name = $_POST['name'] ?? '';
    $description = $_POST['description'] ?? '';

    if (empty($listId)) {
        http_response_code(400); // Bad Request
        echo json_encode(['error' => 'List ID is required']);
        exit;
    }

    if (empty($name)) {
        http_response_code(400); // Bad Request
        echo json_encode(['error' => 'Card name is required']);
        exit;
    }

    // Get the current maximum position for cards in the list
    $stmt = $conn->prepare("SELECT MAX(position) AS max_position FROM cards WHERE list_id = ?");
    $stmt->bind_param("i", $listId);
    $stmt->execute();
    $result = $stmt->get_result();
    $maxPosition = $result->fetch_assoc()['max_position'] ?? 0;
    $newPosition = $maxPosition + 1; // New card's position

    $stmt->close();

    // Insert the new card into the database
    $stmt = $conn->prepare("INSERT INTO cards (list_id, title, description, position) VALUES (?, ?, ?, ?)");
    $stmt->bind_param("issi", $listId, $name, $description, $newPosition);

    if ($stmt->execute()) {
        http_response_code(201); // Created
        echo json_encode(['message' => 'Card added successfully']);
    } else {
        http_response_code(500); // Internal Server Error
        echo json_encode(['error' => 'Failed to add card']);
    }

    $stmt->close();
} else {
    http_response_code(405); // Method Not Allowed
    echo json_encode(['error' => 'Only POST method is allowed']);
}
