<?php
require_once '../../cors/cors.php';
require_once '../../config/database.php';
require_once '../../config/auth.php';

if ($_SERVER['REQUEST_METHOD'] == 'POST') {
    // Get the token from the Authorization header
    $headers = apache_request_headers();
    $authHeader = $headers['Authorization'] ?? '';

    if (!$authHeader || !preg_match('/Bearer\s(\S+)/', $authHeader, $matches)) {
        http_response_code(401); // Unauthorized
        echo json_encode(['error' => 'Unauthorized. Token is required.']);
        exit;
    }

    $token = $matches[1];
    $userData = validateToken($token);

    if (!$userData) {
        http_response_code(401); // Unauthorized
        echo json_encode(['error' => 'Invalid or expired token']);
        exit;
    }

    // Get the card ID and user ID
    $cardId = $_POST['card_id'] ?? '';
    $userId = $_POST['user_id'] ?? '';

    if (empty($cardId) || empty($userId)) {
        http_response_code(400); // Bad Request
        echo json_encode(['error' => 'Card ID and User ID are required']);
        exit;
    }

    // Check if the card exists
    $stmt = $conn->prepare("SELECT id FROM cards WHERE id = ?");
    $stmt->bind_param("i", $cardId);
    $stmt->execute();
    $result = $stmt->get_result();

    if ($result->num_rows == 0) {
        http_response_code(404); // Not Found
        echo json_encode(['error' => 'Card not found']);
        exit;
    }

    $stmt->close();

    // Check if the user exists
    $stmt = $conn->prepare("SELECT id FROM users WHERE id = ?");
    $stmt->bind_param("i", $userId);
    $stmt->execute();
    $result = $stmt->get_result();

    if ($result->num_rows == 0) {
        http_response_code(404); // Not Found
        echo json_encode(['error' => 'User not found']);
        exit;
    }

    $stmt->close();

    // Assign the user to the card
    $stmt = $conn->prepare("INSERT INTO card_assignees (card_id, user_id) VALUES (?, ?)");
    $stmt->bind_param("ii", $cardId, $userId);

    if ($stmt->execute()) {
        http_response_code(201); // Created
        echo json_encode(['message' => 'User assigned to card successfully']);
    } else {
        http_response_code(500); // Internal Server Error
        echo json_encode(['error' => 'Failed to assign user to card']);
    }

    $stmt->close();
} else {
    http_response_code(405); // Method Not Allowed
    echo json_encode(['error' => 'Only POST method is allowed']);
}
