<?php
require_once '../../cors/cors.php';
require_once '../../config/database.php';
require_once '../../config/auth.php';

if ($_SERVER['REQUEST_METHOD'] == 'GET') {
    // Validate token
    $headers = apache_request_headers();
    $authHeader = $headers['Authorization'] ?? '';

    if (!$authHeader || !preg_match('/Bearer\s(\S+)/', $authHeader, $matches)) {
        http_response_code(401); // Unauthorized
        echo json_encode(['error' => 'Unauthorized. Token is required.']);
        exit;
    }

    $token = $matches[1];
    $userData = validateToken($token);

    if (!$userData) {
        http_response_code(401); // Unauthorized
        echo json_encode(['error' => 'Invalid or expired token']);
        exit;
    }

    // Get list ID from query parameters
    $listId = $_GET['list_id'] ?? '';

    if (empty($listId)) {
        http_response_code(400); // Bad Request
        echo json_encode(['error' => 'List ID is required']);
        exit;
    }

    // Fetch cards under the specified list, ordered by position
    $stmt = $conn->prepare("SELECT `id`, `title`, `description`, `position`, `created_at` FROM `cards` WHERE `list_id` = ? ORDER BY `position` ASC");
    $stmt->bind_param("i", $listId);
    $stmt->execute();
    $result = $stmt->get_result();

    $cards = [];
    while ($row = $result->fetch_assoc()) {
        $cards[] = $row;
    }

    http_response_code(200); // OK
    echo json_encode($cards);

    $stmt->close();
} else {
    http_response_code(405); // Method Not Allowed
    echo json_encode(['error' => 'Only GET method is allowed']);
}
