<?php
require_once '../../cors/cors.php';
require_once '../../config/database.php';
require_once '../../config/auth.php';

if ($_SERVER['REQUEST_METHOD'] == 'POST') {
    // Get the token from the Authorization header
    $headers = apache_request_headers();
    $authHeader = $headers['Authorization'] ?? '';

    if (!$authHeader || !preg_match('/Bearer\s(\S+)/', $authHeader, $matches)) {
        http_response_code(401); // Unauthorized
        echo json_encode(['error' => 'Unauthorized. Token is required.']);
        exit;
    }

    $token = $matches[1];
    $userData = validateToken($token);

    if (!$userData) {
        http_response_code(401); // Unauthorized
        echo json_encode(['error' => 'Invalid or expired token']);
        exit;
    }

    // Get card ID
    $cardId = $_POST['card_id'] ?? '';

    if (empty($cardId)) {
        http_response_code(400); // Bad Request
        echo json_encode(['error' => 'Card ID is required']);
        exit;
    }

    // Check if the card exists
    $stmt = $conn->prepare("SELECT id FROM cards WHERE id = ?");
    $stmt->bind_param("i", $cardId);
    $stmt->execute();
    $result = $stmt->get_result();

    if ($result->num_rows == 0) {
        http_response_code(404); // Not Found
        echo json_encode(['error' => 'Card not found']);
        exit;
    }

    $stmt->close();

    // Handle file upload
    if (!isset($_FILES['attachment']) || $_FILES['attachment']['error'] != UPLOAD_ERR_OK) {
        http_response_code(400); // Bad Request
        echo json_encode(['error' => 'A valid file is required']);
        exit;
    }

    $file = $_FILES['attachment'];
    $uploadDir = '../../uploads/attachments/';
    $fileName = uniqid() . '-' . basename($file['name']);
    $filePath = $uploadDir . $fileName;

    $ownPath = "http://localhost/project/uploads/attachments/" . $fileName;

    // Ensure the upload directory exists
    if (!is_dir($uploadDir)) {
        mkdir($uploadDir, 0777, true);
    }

    if (move_uploaded_file($file['tmp_name'], $filePath)) {
        // Insert the attachment into the database
        $stmt = $conn->prepare("INSERT INTO attachments (card_id, file_name, file_path) VALUES (?, ?, ?)");
        $stmt->bind_param("iss", $cardId, $fileName, $ownPath);

        if ($stmt->execute()) {
            http_response_code(201); // Created
            echo json_encode(['message' => 'File uploaded successfully', 'file_name' => $fileName, 'file_path' => $ownPath]);
        } else {
            http_response_code(500); // Internal Server Error
            echo json_encode(['error' => 'Failed to save file attachment']);
        }

        $stmt->close();
    } else {
        http_response_code(500); // Internal Server Error
        echo json_encode(['error' => 'Failed to upload file']);
    }
} else {
    http_response_code(405); // Method Not Allowed
    echo json_encode(['error' => 'Only POST method is allowed']);
}
