<?php
require_once '../../cors/cors.php';
require_once '../../config/database.php';
require_once '../../config/auth.php';

if ($_SERVER['REQUEST_METHOD'] == 'POST') {
    // Get the token from the Authorization header
    $headers = apache_request_headers();
    $authHeader = $headers['Authorization'] ?? '';

    if (!$authHeader || !preg_match('/Bearer\s(\S+)/', $authHeader, $matches)) {
        http_response_code(401); // Unauthorized
        echo json_encode(['error' => 'Unauthorized. Token is required.']);
        exit;
    }

    $token = $matches[1];
    $userData = validateToken($token);

    if (!$userData) {
        http_response_code(401); // Unauthorized
        echo json_encode(['error' => 'Invalid or expired token']);
        exit;
    }

    // Get card ID
    $cardId = $_POST['card_id'] ?? '';

    if (empty($cardId)) {
        http_response_code(400); // Bad Request
        echo json_encode(['error' => 'Card ID is required']);
        exit;
    }

    // Check if the card exists
    $stmt = $conn->prepare("SELECT id FROM cards WHERE id = ?");
    $stmt->bind_param("i", $cardId);
    $stmt->execute();
    $result = $stmt->get_result();

    if ($result->num_rows == 0) {
        http_response_code(404); // Not Found
        echo json_encode(['error' => 'Card not found']);
        exit;
    }

    $stmt->close();

    // Handle file upload
    if (!isset($_FILES['cover_photo']) || $_FILES['cover_photo']['error'] != UPLOAD_ERR_OK) {
        http_response_code(400); // Bad Request
        echo json_encode(['error' => 'A valid cover photo is required']);
        exit;
    }

    $file = $_FILES['cover_photo'];
    $uploadDir = '../../uploads/cover_photos/';
    $fileName = uniqid() . '-' . basename($file['name']);
    $filePath = $uploadDir . $fileName;

    $ownPath = "http://localhost/project/uploads/cover_photos/" . $fileName;

    // Ensure the upload directory exists
    if (!is_dir($uploadDir)) {
        mkdir($uploadDir, 0777, true);
    }

    if (move_uploaded_file($file['tmp_name'], $filePath)) {
        // Update the card with the cover photo path
        $stmt = $conn->prepare("UPDATE cards SET cover_photo = ?, photo_path = ? WHERE id = ?");
        $stmt->bind_param("ssi", $fileName, $ownPath, $cardId);

        if ($stmt->execute()) {
            http_response_code(200); // OK
            echo json_encode(['message' => 'Cover photo uploaded successfully', 'cover_photo' => $fileName, 'photo_path' => $ownPath]);
        } else {
            http_response_code(500); // Internal Server Error
            echo json_encode(['error' => 'Failed to update card with cover photo']);
        }

        $stmt->close();
    } else {
        http_response_code(500); // Internal Server Error
        echo json_encode(['error' => 'Failed to upload cover photo']);
    }
} else {
    http_response_code(405); // Method Not Allowed
    echo json_encode(['error' => 'Only POST method is allowed']);
}
