<?php
require_once '../../cors/cors.php';
require_once '../../config/database.php';
require_once '../../config/auth.php';

if ($_SERVER['REQUEST_METHOD'] == 'POST') {
    // Get the token from the Authorization header
    $headers = apache_request_headers();
    $authHeader = $headers['Authorization'] ?? '';

    if (!$authHeader || !preg_match('/Bearer\s(\S+)/', $authHeader, $matches)) {
        http_response_code(401); // Unauthorized
        echo json_encode(['error' => 'Unauthorized. Token is required.']);
        exit;
    }

    $token = $matches[1];
    $userData = validateToken($token);

    if (!$userData) {
        http_response_code(401); // Unauthorized
        echo json_encode(['error' => 'Invalid or expired token']);
        exit;
    }

    // Get card ID and comment data
    $cardId = $_POST['card_id'] ?? '';
    $comment = $_POST['comment'] ?? '';

    if (empty($cardId)) {
        http_response_code(400); // Bad Request
        echo json_encode(['error' => 'Card ID is required']);
        exit;
    }

    if (empty($comment)) {
        http_response_code(400); // Bad Request
        echo json_encode(['error' => 'Comment is required']);
        exit;
    }

    // Insert the comment into the database
    $stmt = $conn->prepare("INSERT INTO comments (card_id, user_id, comment) VALUES (?, ?, ?)");
    $stmt->bind_param("iis", $cardId, $userData['user_id'], $comment);

    if ($stmt->execute()) {
        http_response_code(201); // Created
        echo json_encode(['message' => 'Comment added successfully']);
    } else {
        http_response_code(500); // Internal Server Error
        echo json_encode(['error' => 'Failed to add comment']);
    }

    $stmt->close();
} else {
    http_response_code(405); // Method Not Allowed
    echo json_encode(['error' => 'Only POST method is allowed']);
}
