<?php
require_once '../../cors/cors.php';
require_once '../../config/database.php';
require_once '../../config/auth.php';

if ($_SERVER['REQUEST_METHOD'] == 'POST') {
    // Get the token from the Authorization header
    $headers = apache_request_headers();
    $authHeader = $headers['Authorization'] ?? '';

    if (!$authHeader || !preg_match('/Bearer\s(\S+)/', $authHeader, $matches)) {
        http_response_code(401); // Unauthorized
        echo json_encode(['error' => 'Unauthorized. Token is required.']);
        exit;
    }

    $token = $matches[1];
    $userData = validateToken($token);

    if (!$userData) {
        http_response_code(401); // Unauthorized
        echo json_encode(['error' => 'Invalid or expired token']);
        exit;
    }

    // Get the list data
    $boardId = $_POST['board_id'] ?? '';
    $name = $_POST['name'] ?? '';

    if (empty($boardId)) {
        http_response_code(400); // Bad Request
        echo json_encode(['error' => 'Board ID is required']);
        exit;
    }

    if (empty($name)) {
        http_response_code(400); // Bad Request
        echo json_encode(['error' => 'List name is required']);
        exit;
    }

    // Get the current maximum position for lists in the board
    $stmt = $conn->prepare("SELECT MAX(position) AS max_position FROM lists WHERE board_id = ?");
    $stmt->bind_param("i", $boardId);
    $stmt->execute();
    $result = $stmt->get_result();
    $maxPosition = $result->fetch_assoc()['max_position'] ?? 0;
    $newPosition = $maxPosition + 1; // New list's position

    $stmt->close();

    // Insert the new list into the database
    $stmt = $conn->prepare("INSERT INTO lists (board_id, name, position) VALUES (?, ?, ?)");
    $stmt->bind_param("isi", $boardId, $name, $newPosition);

    if ($stmt->execute()) {
        http_response_code(200); // Created
        echo json_encode(['message' => 'List added successfully']);
    } else {
        http_response_code(500); // Internal Server Error
        echo json_encode(['error' => 'Failed to add list']);
    }

    $stmt->close();
} else {
    http_response_code(405); // Method Not Allowed
    echo json_encode(['error' => 'Only POST method is allowed']);
}
