<?php
require_once '../../cors/cors.php';
require_once '../../config/database.php';
require_once '../../config/auth.php';

if ($_SERVER['REQUEST_METHOD'] == 'PUT') {
    // Get the token from the Authorization header
    $headers = apache_request_headers();
    $authHeader = $headers['Authorization'] ?? '';

    if (!$authHeader || !preg_match('/Bearer\s(\S+)/', $authHeader, $matches)) {
        http_response_code(401); // Unauthorized
        echo json_encode(['error' => 'Unauthorized. Token is required.']);
        exit;
    }

    $token = $matches[1];
    $userData = validateToken($token);

    if (!$userData) {
        http_response_code(401); // Unauthorized
        echo json_encode(['error' => 'Invalid or expired token']);
        exit;
    }

    // Parse the raw JSON body
    $input = json_decode(file_get_contents("php://input"), true);
    $listId = $input['id'] ?? '';
    $name = $input['name'] ?? '';

    if (empty($listId) || empty($name)) {
        http_response_code(400); // Bad Request
        echo json_encode(['error' => 'List ID and name are required']);
        exit;
    }

    // Check if the list exists
    $stmt = $conn->prepare("SELECT id FROM lists WHERE id = ?");
    $stmt->bind_param("i", $listId);
    $stmt->execute();
    $result = $stmt->get_result();

    if ($result->num_rows == 0) {
        http_response_code(404); // Not Found
        echo json_encode(['error' => 'List not found']);
        exit;
    }

    $stmt->close();

    // Update the list name
    $stmt = $conn->prepare("UPDATE lists SET name = ? WHERE id = ?");
    $stmt->bind_param("si", $name, $listId);

    if ($stmt->execute()) {
        http_response_code(200); // OK
        echo json_encode(['message' => 'List updated successfully']);
    } else {
        http_response_code(500); // Internal Server Error
        echo json_encode(['error' => 'Failed to update list']);
    }

    $stmt->close();
} else {
    http_response_code(405); // Method Not Allowed
    echo json_encode(['error' => 'Only PUT method is allowed']);
}
