<?php
require_once '../../cors/cors.php';
require_once '../../config/database.php';
require_once '../../config/auth.php';

// Validate token
$headers = apache_request_headers();
$authHeader = $headers['Authorization'] ?? '';

if (!$authHeader || !preg_match('/Bearer\s(\S+)/', $authHeader, $matches)) {
    http_response_code(401); // Unauthorized
    echo json_encode(['error' => 'Unauthorized. Token is required.']);
    exit;
}

$token = $matches[1];
$userData = validateToken($token);

if (!$userData) {
    http_response_code(401); // Unauthorized
    echo json_encode(['error' => 'Invalid or expired token']);
    exit;
}

// Get board ID from query parameters
$boardId = $_GET['board_id'] ?? '';

if (empty($boardId)) {
    http_response_code(400); // Bad Request
    echo json_encode(['error' => 'Board ID is required']);
    exit;
}

// Fetch lists under the specified board, ordered by position
$stmt = $conn->prepare("SELECT id, name, position, created_at FROM lists WHERE board_id = ? ORDER BY position ASC");
$stmt->bind_param("i", $boardId);
$stmt->execute();
$result = $stmt->get_result();

$lists = [];
while ($row = $result->fetch_assoc()) {
    $lists[] = $row;
}

http_response_code(200); // OK
echo json_encode($lists);

$stmt->close();
