<?php
require_once '../../cors/cors.php';
require_once '../../config/database.php';
require_once '../../config/auth.php';

if ($_SERVER['REQUEST_METHOD'] == 'PUT') {
    // Get the token from the Authorization header
    $headers = apache_request_headers();
    $authHeader = $headers['Authorization'] ?? '';

    if (!$authHeader || !preg_match('/Bearer\s(\S+)/', $authHeader, $matches)) {
        http_response_code(401); // Unauthorized
        echo json_encode(['error' => 'Unauthorized. Token is required.']);
        exit;
    }

    $token = $matches[1];
    $userData = validateToken($token);

    if (!$userData) {
        http_response_code(401); // Unauthorized
        echo json_encode(['error' => 'Invalid or expired token']);
        exit;
    }

    // Parse the raw JSON body
    $input = json_decode(file_get_contents("php://input"), true);
    $listId = $input['id'] ?? '';
    $newPosition = $input['position'] ?? '';

    if (empty($listId) || !is_numeric($newPosition)) {
        http_response_code(400); // Bad Request
        echo json_encode(['error' => 'List ID and new position are required']);
        exit;
    }

    // Update the list position
    $stmt = $conn->prepare("UPDATE lists SET position = ? WHERE id = ?");
    $stmt->bind_param("ii", $newPosition, $listId);

    if ($stmt->execute()) {
        http_response_code(200); // OK
        echo json_encode(['message' => 'List position updated successfully']);
    } else {
        http_response_code(500); // Internal Server Error
        echo json_encode(['error' => 'Failed to update list position']);
    }

    $stmt->close();
} else {
    http_response_code(405); // Method Not Allowed
    echo json_encode(['error' => 'Only PUT method is allowed']);
}
