<?php
require_once '../../cors/cors.php';
require_once '../../config/database.php';

if ($_SERVER['REQUEST_METHOD'] == 'POST') {
    $email = $_POST['email'] ?? '';
    $password = $_POST['password'] ?? '';

    // Check for empty fields
    if (empty($email)) {
        http_response_code(400); // Bad Request
        echo json_encode(['error' => 'Email is required']);
        exit;
    }

    if (empty($password)) {
        http_response_code(400); // Bad Request
        echo json_encode(['error' => 'Password is required']);
        exit;
    }

    // Check if the user exists
    $stmt = $conn->prepare("SELECT * FROM users WHERE email = ?");
    $stmt->bind_param("s", $email);
    $stmt->execute();
    $result = $stmt->get_result();

    if ($result->num_rows == 0) {
        http_response_code(401); // Unauthorized
        echo json_encode(['error' => 'Invalid email or password']);
        exit;
    }

    $user = $result->fetch_assoc();

    // Verify the password
    if (password_verify($password, $user['password'])) {
        // Generate a dynamic token
        $token = base64_encode(json_encode([
            'user_id' => $user['id'],
            'email' => $email,
            'timestamp' => time(),
            'random' => bin2hex(random_bytes(8)) // Ensure uniqueness
        ]));

        // Return the token to the client
        http_response_code(200); // OK
        echo json_encode([
            'message' => 'Login successful',
            'token' => $token,
            'data' => $user
        ]);
    } else {
        http_response_code(401); // Unauthorized
        echo json_encode(['error' => 'Invalid email or password']);
    }

    $stmt->close();
} else {
    http_response_code(405); // Method Not Allowed
    echo json_encode(['error' => 'Only POST method is allowed']);
}
