<?php
require_once '../../cors/cors.php';
require_once '../../config/database.php';

if ($_SERVER['REQUEST_METHOD'] == 'POST') {
    $name = $_POST['name'] ?? '';
    $email = $_POST['email'] ?? '';
    $password = $_POST['password'] ?? '';

    // Check if all fields are provided
    if (empty($name) && empty($email) && empty($password)) {
        http_response_code(400); // Bad Request
        echo json_encode(['error' => 'All fields are required']);
        exit;
    }

    if (empty($name)) {
        http_response_code(400); // Bad Request
        echo json_encode(['error' => 'Name field is required']);
        exit;
    }

    if (empty($email)) {
        http_response_code(400); // Bad Request
        echo json_encode(['error' => 'Email field is required']);
        exit;
    }

    if (empty($password)) {
        http_response_code(400); // Bad Request
        echo json_encode(['error' => 'Password field is required']);
        exit;
    }

    if (!empty($name) && !empty($email) && !empty($password)) {
        // Check if email already exists
        $checkStmt = $conn->prepare("SELECT id FROM `users` WHERE `email` = ?");
        $checkStmt->bind_param("s", $email);
        $checkStmt->execute();
        $result = $checkStmt->get_result();

        if ($result->num_rows > 0) {
            http_response_code(409); // Conflict
            echo json_encode(['error' => 'A user with this email already exists']);
            $checkStmt->close();
            exit;
        }
        $checkStmt->close();

        // If email is not found, proceed with registration
        $hashedPassword = password_hash($password, PASSWORD_BCRYPT);

        $stmt = $conn->prepare("INSERT INTO `users` (`name`, `email`, `password`) VALUES (?, ?, ?)");
        $stmt->bind_param("sss", $name, $email, $hashedPassword);

        if ($stmt->execute()) {
            http_response_code(200); // Created
            echo json_encode(['message' => 'User registered successfully']);
        } else {
            http_response_code(500); // Internal Server Error
            echo json_encode(['error' => 'Registration failed']);
        }

        $stmt->close();
    }
} else {
    http_response_code(405); // Method Not Allowed
    echo json_encode(['error' => 'Only POST method is allowed']);
}
