<?php
require_once '../../cors/cors.php';
require_once '../../config/database.php';
require_once '../../config/auth.php';

if ($_SERVER['REQUEST_METHOD'] == 'POST') {

    // Get the token from the Authorization header
    $headers = apache_request_headers();
    $authHeader = $headers['Authorization'] ?? '';

    if (!$authHeader || !preg_match('/Bearer\s(\S+)/', $authHeader, $matches)) {
        http_response_code(401); // Unauthorized
        echo json_encode(['error' => 'Unauthorized. Token is required.']);
        exit;
    }

    $token = $matches[1];
    $userData = validateToken($token);

    if (!$userData) {
        http_response_code(401); // Unauthorized
        echo json_encode(['error' => 'Invalid or expired token']);
        exit;
    }

    // Get the workspace data
    $name = $_POST['name'] ?? '';
    $description = $_POST['description'] ?? '';

    if (empty($name)) {
        http_response_code(400); // Bad Request
        echo json_encode(['error' => 'Workspace name is required']);
        exit;
    }

    // Insert the workspace into the database
    $stmt = $conn->prepare("INSERT INTO workspaces (`name`, `description`, `created_by`) VALUES (?, ?, ?)");
    $stmt->bind_param("ssi", $name, $description, $userData['user_id']);

    if ($stmt->execute()) {
        http_response_code(200); // Created
        echo json_encode(['message' => 'Workspace added successfully']);
    } else {
        http_response_code(500); // Internal Server Error
        echo json_encode(['error' => 'Failed to add workspace']);
    }

    $stmt->close();
} else {
    http_response_code(405); // Method Not Allowed
    echo json_encode(['error' => 'Only POST method is allowed']);
}
