<?php
require_once '../../cors/cors.php';
require_once '../../config/database.php';
require_once '../../config/auth.php';

if ($_SERVER['REQUEST_METHOD'] == 'GET') {
    // Validate token
    $headers = apache_request_headers();
    $authHeader = $headers['Authorization'] ?? '';

    if (!$authHeader || !preg_match('/Bearer\s(\S+)/', $authHeader, $matches)) {
        http_response_code(401); // Unauthorized
        echo json_encode(['error' => 'Unauthorized. Token is required.']);
        exit;
    }

    $token = $matches[1];
    $userData = validateToken($token);

    if (!$userData) {
        http_response_code(401); // Unauthorized
        echo json_encode(['error' => 'Invalid or expired token']);
        exit;
    }

    // Fetch workspaces created by the user
    $stmt = $conn->prepare("SELECT id, name, description, created_at FROM workspaces");
    // $stmt->bind_param("i", $userData['user_id']);
    $stmt->execute();
    $result = $stmt->get_result();

    $workspaces = [];
    while ($row = $result->fetch_assoc()) {
        $workspaces[] = $row;
    }

    http_response_code(200); // OK
    echo json_encode($workspaces);

    $stmt->close();
} else {
    http_response_code(405); // Method Not Allowed
    echo json_encode(['error' => 'Only GET method is allowed']);
}
