<?php
require_once '../../cors/cors.php';
require_once '../../config/database.php';
require_once '../../config/auth.php';

if ($_SERVER['REQUEST_METHOD'] == 'GET') {
    // Validate token
    $headers = apache_request_headers();
    $authHeader = $headers['Authorization'] ?? '';

    if (!$authHeader || !preg_match('/Bearer\s(\S+)/', $authHeader, $matches)) {
        http_response_code(401); // Unauthorized
        echo json_encode(['error' => 'Unauthorized. Token is required.']);
        exit;
    }

    $token = $matches[1];
    $userData = validateToken($token);

    if (!$userData) {
        http_response_code(401); // Unauthorized
        echo json_encode(['error' => 'Invalid or expired token']);
        exit;
    }

    // Fetch all workspaces
    $stmt = $conn->prepare("SELECT id, name, description FROM workspaces");
    $stmt->execute();
    $result = $stmt->get_result();

    $workspaces = [];
    
    while ($workspace = $result->fetch_assoc()) {
        $workspaceId = $workspace['id'];
        
        // Fetch boards (boards) for this workspace
        $boardStmt = $conn->prepare("SELECT id,name, description FROM boards WHERE workspace_id = ?");
        $boardStmt->bind_param("i", $workspaceId);
        $boardStmt->execute();
        $boardResult = $boardStmt->get_result();
        
        $boards = [];
        while ($board = $boardResult->fetch_assoc()) {
            $boards[] = [
                'id' => $board['id'],
                'name' => $board['name'],
                'description' => $board['description']
            ];
        }

        // Add the workspace and its associated boards (boards) to the response
        $workspaces[] = [
            'workSpace_Id' => $workspace['id'],
            'name' => $workspace['name'],
            'description' => $workspace['description'],
            'boards' => $boards
        ];

        $boardStmt->close();
    }

    http_response_code(200); // OK
    echo json_encode($workspaces);

    $stmt->close();
} else {
    http_response_code(405); // Method Not Allowed
    echo json_encode(['error' => 'Only GET method is allowed']);
}
?>
